package Task::BeLike::JMATES::Play;

use 5.010000;
use strict;
use warnings;
our $VERSION = '0.14';

1;
__END__

=head1 NAME

Task::BeLike::JMATES::Play - modules used by JMATES (not for work)

=head1 SYNOPSIS

  # and likely also set in your ~/.cpan/CPAN/MyConfig.pm:
  #   'prerequisites_policy' => q[follow],
  export PERL_MM_USE_DEFAULT=1

  # install for whatever Perl cpan + environment points to
  cpan Task::BeLike::JMATES::Play

=head1 DESCRIPTION

Modules used by JMATES not for work (that is, for fun).

=head1 HISTORY

See the git repository, and documentation on how the (public) git
history is minimized in L<Task::BeLike::JMATES>.

=head1 SEE ALSO

L<http://github.com/thrig/Task-BeLike-JMATES-Play>,
L<Task::BeLike::JMATES>, L<Task::BeLike::JMATES::WorkWorkWork>

=head1 AUTHOR

thrig - Jeremy Mates (cpan:JMATES) C<< <jmates at cpan.org> >>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2013-2015 Jeremy Mates

This module is free software; you can redistribute it and/or modify it
under the Artistic License (2.0).

=cut
